@@ -516,7 +516,7 @@ class Git(object):
         net_match = re_host.search(url)
         if net_match:
             if net_match.group(3):
-                return int(net_match.group(3)), net_match.group(2)
+                return int(net_match.group(3)[1:]), net_match.group(2)
             return net_protocols[net_match.group(1)], net_match.group(2)
         re_scp = re.compile("(?:[^@]+@)?([^:]+):(//)?")
         scp_match = re_scp.search(url)
